@@ -1,5 +1,5 @@
 package Playwright;
-$Playwright::VERSION = '0.010';
+$Playwright::VERSION = '0.011';
 use strict;
 use warnings;
 
@@ -7,7 +7,6 @@ use warnings;
 use 5.006;
 use v5.28.0;    # Before 5.006, v5.10.0 would not be understood.
 
-use File::pushd;
 use File::ShareDir();
 use File::Basename();
 use Cwd();
@@ -34,48 +33,44 @@ sub _check_node {
     confess("node must exist, be in your PATH and executable")
       unless $node_bin && -x $node_bin;
 
-    my $global_install = '';
     my $path2here =
       File::Basename::dirname( Cwd::abs_path( $INC{'Playwright.pm'} ) );
 
     # Make sure it's possible to start the server
-    $server_bin = "$path2here/../bin/playwright_server";
-    if ( !-f $server_bin ) {
-        $server_bin     = File::Which::which('playwright_server');
-        $global_install = 1;
-    }
-    confess("Can't locate Playwright server in '$server_bin'!")
-      unless -f $server_bin;
+    $server_bin = File::Which::which('playwright_server');
+    confess(
+        "Can't locate playwright_server!
+    Please ensure it is installed in your PATH.
+    If you installed this module from CPAN, it should already be."
+    ) unless $server_bin && -x $server_bin;
 
     # Attempt to start the server.  If we can't do this, we almost certainly have dependency issues.
     my ($output) =
       capture_merged { system( $node_bin, $server_bin, '--check' ) };
     return if $output =~ m/OK/;
 
-    # Check for the necessary modules, this relies on package.json
-    my $npm_bin = File::Which::which('npm');
-    confess("npm must exist and be executable") unless -x $npm_bin;
+    warn $output if $output;
 
-    # pushd/popd closure
-    {
-        my $curdir = pushd( File::Basename::dirname($server_bin) );
+    confess(
+        "playwright_server could not run successfully.
+    See the above error message for why.
+    It's likely to be unmet dependencies, or a NODE_PATH issue.
 
-        # Attempt to install deps automatically.
-        confess(
-            "Production install of node dependencies must be done manually by nonroot users. Run the following:\n\n pushd '$curdir' && sudo npm i yargs express playwright uuid; popd\n\nIf this doesn't resolve the issue, export NODE_PATH='$curdir/node_modules'."
-        ) if $global_install;
+    Install of node dependencies must be done manually.
+    Run the following:
 
-        my $err = capture_stderr { qx{npm i} };
+    npm i express playwright uuid
+    sudo npx playwright install-deps
+    export NODE_PATH=\"\$(pwd)/node_modules\".
 
-        # XXX apparently doing it 'once more with feeling' fixes issues on windows, lol
-        $err = capture_stderr { qx{npm i} };
-        my $exit = $? >> 8;
+    If you still experience issues, run the following:
+
+    NODE_DEBUG=module playwright_server --check
+
+    This should tell you why node can't find the deps you have installed.
+    "
+    );
 
-        # Ignore failing for bogus reasons
-        if ( $err !~ m/package-lock/ ) {
-            confess("Error installing node dependencies:\n$err") if $exit;
-        }
-    }
 }
 
 sub _build_classes {
@@ -321,7 +316,7 @@ Playwright - Perl client for Playwright
 
 =head1 VERSION
 
-version 0.010
+version 0.011
 
 =head1 SYNOPSIS
 
@@ -369,7 +364,7 @@ See example.pl for a more thoroughly fleshed-out display on how to use this modu
 
 =head3 Getting Started
 
-When using the playwright module for the first time, you may be told to install dependencies.
+When using the playwright module for the first time, you may be told to install node.js libraries.
 It should provide you with instructions which will get you working right away.
 
 However, depending on your node installation this may not work due to dependencies for node.js not being in the expected location.
